Jupyter Client |version|
========================

This package provides the Python API for starting, managing and communicating
with Jupyter kernels.

.. important::
   This document contains the authoritative description of the
   Jupyter messaging protocol. All developers are strongly encouraged to
   keep it updated as the implementation evolves, so that we have a single
   common reference for all protocol details.


.. toctree::
   :maxdepth: 2
   :caption: User Documentation

   messaging

.. toctree::
   :maxdepth: 2
   :caption: Developer documentation

   kernels
   wrapperkernels
   provisioning
   pending-kernels

.. toctree::
   :maxdepth: 2
   :caption: API

   API Docs <api/modules>

.. toctree::
    :maxdepth: 2
    :caption: Changes

    changelog
    migration


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
